@@ -24,7 +24,11 @@ class DBBase:
     def exec(self, sql: str, commit: bool = True):
         self._cur.execute(sql)
         if commit:
-            return self._conn.commit()
+            self._conn.commit()
+
+    def select(self, sql):
+        self._cur.execute(sql)
+        return self._cur.fetchone()
 
     def get_data_iter(self, table_name: str, cols: List[str], condition: Union[str, None]) -> Iterator[Dict]:
         self._cur.execute(self._select_sql(table_name, cols, condition))
@@ -43,7 +47,7 @@ class DBBase:
         if condition is not None:
             return f"SELECT {','.join(cols)} " \
                    f"FROM {table_name} " \
-                   f"WHERE {condition}"
+                   f"{condition}"
         else:
             return f"SELECT {','.join(cols)} " \
                    f"FROM {table_name} "
